@@ -120,5 +120,6 @@ class InstallTarget(Target):
                             logger.info("Now performing installation step: %s", step.__name__)
                             step(args, work_dir, http_download)
         except Exception:
-            logger.exception("Installation failed")
+            # Note: don't use logger.exception here, it doesn't have the `extra` kwarg on Python 2.6.
+            logger.error("Installation failed", exc_info=True, extra={"cookbook_version": args.release})
             raise exception.InstallerException(args.log_file)
